@@ -60,9 +60,7 @@ class RemoteLOCAL(RemoteBASE):
             # cache files are set to be read-only for everyone
             self._file_mode = stat.S_IREAD | stat.S_IRGRP | stat.S_IROTH
 
-        # A clunky way to detect cache dir
-        storagepath = config.get(Config.SECTION_LOCAL_STORAGEPATH, None)
-        cache_dir = config.get(Config.SECTION_REMOTE_URL, storagepath)
+        cache_dir = config.get(Config.SECTION_REMOTE_URL)
 
         if cache_dir is not None and not os.path.isabs(cache_dir):
             cwd = config[Config.PRIVATE_CWD]
@@ -185,7 +183,7 @@ class RemoteLOCAL(RemoteBASE):
         # will get something like: `too many links error`
         #
         # This is because all those empty files will have the same checksum
-        # (i.e. 68b329da9893e34099c7d8ad5cb9c940), therfore, they will be
+        # (i.e. 68b329da9893e34099c7d8ad5cb9c940), therefore, they will be
         # linked to the same file in the cache.
         #
         # From https://en.wikipedia.org/wiki/Hard_link
